@@ -22,7 +22,6 @@ from onefuzztypes.primitives import Container, Directory
 
 from onefuzz.api import UUID_EXPANSION, Command, Onefuzz
 
-from .azcopy import azcopy_sync
 from .backend import wait
 from .rdp import rdp_connect
 from .ssh import ssh_connect
@@ -35,7 +34,7 @@ DEFAULT_TAIL_DELAY = 10.0
 
 
 class DebugRepro(Command):
-    """ Debug repro instances """
+    """Debug repro instances"""
 
     def _disambiguate(self, vm_id: UUID_EXPANSION) -> str:
         return str(
@@ -75,7 +74,7 @@ class DebugRepro(Command):
 
 
 class DebugNode(Command):
-    """ Debug a specific node on a scaleset """
+    """Debug a specific node on a scaleset"""
 
     def rdp(self, machine_id: UUID_EXPANSION, duration: Optional[int] = 1) -> None:
         node = self.onefuzz.nodes.get(machine_id)
@@ -95,7 +94,7 @@ class DebugNode(Command):
 
 
 class DebugScaleset(Command):
-    """ Debug tasks """
+    """Debug tasks"""
 
     def _get_proxy_setup(
         self, scaleset_id: UUID, machine_id: UUID, port: int, duration: Optional[int]
@@ -172,7 +171,7 @@ class DebugScaleset(Command):
 
 
 class DebugTask(Command):
-    """ Debug a specific job """
+    """Debug a specific job"""
 
     def list_nodes(self, task_id: UUID_EXPANSION) -> Optional[List[NodeAssignment]]:
         task = self.onefuzz.tasks.get(task_id)
@@ -255,7 +254,7 @@ class DebugTask(Command):
 
 
 class DebugJobTask(Command):
-    """ Debug a task for a specific job """
+    """Debug a task for a specific job"""
 
     def _get_task(self, job_id: UUID_EXPANSION, task_type: TaskType) -> UUID:
         for task in self.onefuzz.tasks.list(job_id=job_id):
@@ -273,7 +272,7 @@ class DebugJobTask(Command):
         *,
         duration: Optional[int] = 1,
     ) -> None:
-        """ SSH into the first node running the specified task type in the job """
+        """SSH into the first node running the specified task type in the job"""
         return self.onefuzz.debug.task.ssh(
             self._get_task(job_id, task_type), duration=duration
         )
@@ -285,14 +284,14 @@ class DebugJobTask(Command):
         *,
         duration: Optional[int] = 1,
     ) -> None:
-        """ RDP into the first node running the specified task type in the job """
+        """RDP into the first node running the specified task type in the job"""
         return self.onefuzz.debug.task.rdp(
             self._get_task(job_id, task_type), duration=duration
         )
 
 
 class DebugJob(Command):
-    """ Debug a specific Job """
+    """Debug a specific Job"""
 
     def __init__(self, onefuzz: Any, logger: logging.Logger):
         super().__init__(onefuzz, logger)
@@ -335,28 +334,9 @@ class DebugJob(Command):
         )
 
     def download_files(self, job_id: UUID_EXPANSION, output: Directory) -> None:
-        """ Download the containers by container type for each task in the specified job """
+        """Download the containers by container type for each task in the specified job"""
 
-        to_download = {}
-        tasks = self.onefuzz.tasks.list(job_id=job_id, state=None)
-        if not tasks:
-            raise Exception("no tasks with job_id:%s" % job_id)
-
-        for task in tasks:
-            for container in task.config.containers:
-                info = self.onefuzz.containers.get(container.name)
-                name = os.path.join(container.type.name, container.name)
-                to_download[name] = info.sas_url
-
-        for name in to_download:
-            outdir = os.path.join(output, name)
-            if not os.path.exists(outdir):
-                os.makedirs(outdir)
-            self.logger.info("downloading: %s", name)
-            # security note: the src for azcopy comes from the server which is
-            # trusted in this context, while the destination is provided by the
-            # user
-            azcopy_sync(to_download[name], outdir)
+        self.onefuzz.jobs.containers.download(job_id, output=output)
 
 
 class DebugLog(Command):
@@ -570,7 +550,7 @@ class DebugLog(Command):
 
 
 class DebugNotification(Command):
-    """ Debug notification integrations """
+    """Debug notification integrations"""
 
     def _get_container(
         self, task: Task, container_type: ContainerType
@@ -592,7 +572,7 @@ class DebugNotification(Command):
         report_container_type: ContainerType = ContainerType.unique_reports,
         crash_name: str = "fake-crash-sample",
     ) -> None:
-        """ Inject a report into the first crash reporting task in the specified job """
+        """Inject a report into the first crash reporting task in the specified job"""
 
         tasks = self.onefuzz.tasks.list(job_id=job_id, state=[])
         for task in tasks:
@@ -616,7 +596,7 @@ class DebugNotification(Command):
         report_container_type: ContainerType = ContainerType.unique_reports,
         crash_name: str = "fake-crash-sample",
     ) -> None:
-        """ Inject a report into the specified crash reporting task """
+        """Inject a report into the specified crash reporting task"""
 
         task = self.onefuzz.tasks.get(task_id)
         crashes = self._get_container(task, ContainerType.crashes)
@@ -664,7 +644,7 @@ class DebugNotification(Command):
 
 
 class Debug(Command):
-    """ Debug running jobs """
+    """Debug running jobs"""
 
     def __init__(self, onefuzz: Any, logger: logging.Logger):
         super().__init__(onefuzz, logger)
